Generate a SpatialPoints object with the x and y coordinates corresponding to the best result obtained in an optimized network. The parameter to be passed to this function must be the result of seqPtsOptNet or simPtsOptNet
bestnet(optimnet)a SpatialPoints object
object of class rbga resulting from seqPtsOptNet or simPtsOptNet
See function rbga in the genalg package; for examples see seqPtsOptNet and simPtsOptNet