Learn R Programming

geospt (version 1.0-2)

lalib: Map of boundary enclosing La Libertad Research Center

Description

Map of boundary enclosing La Libertad Research Center

Usage

data(lalib)

Arguments

Format

The format is: Formal class 'SpatialPolygonsDataFrame' [package "sp"]

Santacruz, A. 2010. Design of optimal spatial sampling networks for the monitoring of soil organic carbon at La Libertad Research Center through the application of genetic algorithms. M.Sc. Thesis. National University of Colombia, Bogot. 162 p. (In Spanish)

Details

Map of boundary enclosing La Libertad Research Center. Spatial reference system: UTM 18N

References

Santacruz, A., Rubiano, Y., Melo, C., 2014. Evolutionary optimization of spatial sampling networks designed for the monitoring of soil carbon. In: Hartemink, A., McSweeney, K. (Eds.). Soil Carbon. Series: Progress in Soil Science. (pp. 77-84). Springer. [link]

Santacruz, A., 2011. Evolutionary optimization of spatial sampling networks. An application of genetic algorithms and geostatistics for the monitoring of soil organic carbon. Editorial Acadmica Espaola. 183 p. ISBN: 978-3-8454-9815-7 (In Spanish) [link]

Examples

Run this code
data(lalib)
summary(lalib)
plot(lalib)

Run the code above in your browser using DataLab