Learn R Programming

geospt (version 1.0-0)

rbf.cv: rbf cross validation leave-one-out

Description

Generate the RMSPE value, which is given by the radial basis function with smoothing parameter eta and robustness parameter rho.

Usage

rbf.cv(formula, data, eta, rho, n.neigh, func)

Arguments

Value

returns the RMSPE value

See Also

rbf

Examples

Run this code
data(preci)
coordinates(preci)<-~x+y
rbf.cv(prec~1, preci, eta=0.2589, rho=0, n.neigh=9, func="M")

Run the code above in your browser using DataLab