Learn R Programming

geospt (version 1.0-0)

rbf.cv1: Generates a RMSPE value, result of cross validation leave-one-out

Description

Generate the RMSPE value, which is given by the radial basis function with smoothing parameter eta and robustness parameter rho.

Usage

rbf.cv1(param, formula, data, n.neigh, func)

Arguments

Value

returns the RMSPE value

See Also

rbf

Examples

Run this code
data(preci)
require(nloptr)
coordinates(preci) <- ~x+y
bobyqa(c(0.5, 0.5), rbf.cv1, lower=c(1e-05,0), upper=c(2,2), formula=prec~x+y, data=preci,
    n.neigh=9, func="TRI")
# obtained with the optimal values previously estimated
rbf.cv1(c(0.2126191,0.1454171), prec~x+y, preci, n.neigh=9, func="TRI")

Run the code above in your browser using DataLab