Learn R Programming

geospt (version 0.4-9)

rbf.tcv: rbf cross validation, leave-one-out

Description

Cross validation functions for gaussian (GAU), exponential (EXP), trigonometric (TRI), thin plate spline (TPS), inverse multiquadratic (IM), and multiquadratic (M) radial basis functions (rbf)

Usage

rbf.tcv(sigma, z, coordinates, n.neigh, func)

Arguments

Value

data frame contain the data coordinates, prediction columns, observed values, residuals, the prediction variance, zscore (residual divided by standard error) which left with NA's, and the fold column which is associated to cross-validation count. Prediction columns and residuals are obtained from cross-validation data points

Details

Leave-one-out cross validation (LOOCV) visits a data point, predicts the value at that location by leaving out the observed value, and proceeds with the next data point. The observed value is left out because rbf would otherwise predict the value itself.

See Also

rbf

Examples

Run this code
data(preci)
attach(preci)
rbf.tcv(sigma=0.1460814, z=prec, coordinates=preci[,2:3], n.neigh=9,
    func="TPS")

Run the code above in your browser using DataLab