bestnet: Generate a SpatialPoints object corresponding to the best result obtained in an optimized network
Description
Generate a SpatialPoints object with the x and y coordinates corresponding to the best result obtained in an optimized network. The parameter to be passed to this function must be the result of seqPtsOptNet or simPtsOptNetValue
a SpatialPoints object