geospt-package: Geostatistical Analysis and Design of Optimal Spatial Sampling Networks
Description
A set of functions for: estimation of the variogram through trimmed mean, radial basis functions
(optimization, prediction and cross-validation), summary statistics from cross-validation, pocket plot, and
design of optimal sampling networks through sequential and simultaneous points methodsDetails
ll{
Package: geospt
Type: Package
Version: 1.0-1
Date: 2014-10-07
License: GPL (>= 2)
LazyLoad: yes
}