A set of functions for: estimation of the variogram through trimmed mean, radial basis functions (optimization, prediction and cross-validation), summary statistics from cross-validation, pocket plot, and design of optimal sampling networks through sequential and simultaneous points methods
Carlos Melo <cmelo@udistrital.edu.co>, Ali Santacruz, Oscar Melo <oomelom@unal.edu.co
Maintainer: Ali Santacruz <amsantac@unal.edu.co>
| Package: | geospt |
| Type: | Package |
| Version: | 1.0-4 |
| Date: | 2024-02-19 |
| License: | GPL (>= 2) |
| LazyLoad: | yes |
rbf, est.variograms, seqPtsOptNet, simPtsOptNet