Learn R Programming

geospt (version 0.4-9)

geospt-package: Spatial geostatistics; some geostatistical and radial basis functions, prediction and cross validation; design of optimal spatial sampling networks based on geostatistical modelling

Description

This package contains functions for: estimation of the variogram through trimmed mean, radial basis functions (optimization, prediction and cross-validation), summary statistics from cross-validation, pocket plot, and design of optimal sampling networks through sequential and simultaneous points methods

Arguments

docType

package

Details

ll{ Package: geospt Type: Package Version: 0.4-9 Date: 2012-04-18 License: GPL (>= 2) LazyLoad: yes }

See Also

rbf, est.variograms, seqPtsOptNet, simPtsOptNet